@@ -18,7 +18,7 @@
  *  along with this program.  If not, see <http://www.gnu.org/licenses/>.
  *****************************************************************************/
 
-
+ 
 #ifndef TOOLS_SIMKA_SRC_SIMKAFUSION_HPP_
 #define TOOLS_SIMKA_SRC_SIMKAFUSION_HPP_
 
@@ -214,9 +214,18 @@ public:
 
 		//cout << "lala" << endl;
 		//cout << _execDir << endl;
-
-		_execDir = System::file().getRealPath(execFilename);
-		_execDir = System::file().getDirectory(_execDir) + "/";
+       
+		if (execFilename == "simka") // i.e. simka binary is found in $PATH
+		{
+			//cout << endl << "Debug info : execFilename = simka (i.e. simka binary is found in $PATH)" << endl;
+			_execDir = "";
+		}
+		else
+		{
+			//cout << endl << "Debug info : execFilename = " << execFilename << endl;
+			_execDir = System::file().getRealPath(execFilename);
+			_execDir = System::file().getDirectory(_execDir) + "/";
+		}
 
 		//_options = options;
 
@@ -364,9 +373,20 @@ public:
 			_isClusterMode = false;
 		}
 
+        if (this->_options->getInt(STR_MAX_MEMORY) < 2000)
+        {
+            std::cout << "WARNING: running Simka with low memory is risky. Simka may hang because of that. Consider running with -max-memory X where X > 2000" << std::endl;
+        }
 
 
 
+		if (this->_options->getInt(STR_MAX_MEMORY) < 500)
+        {
+            std::cout << "Please run Simka with higher memory usage than 500 MB" << std::endl;
+            exit(1);
+        }
+
+
 		//_isClusterMode = true;
 
 		//if(this->_options->get(STR_SIMKA_CLUSTER_MODE)){
@@ -601,6 +621,13 @@ public:
     		IBank* bank = Bank::open(inputDir + this->_bankNames[i]);
     		LOCAL(bank);
 
+            // Check that data files are not empty
+            int64_t nbItems = bank->estimateNbItems();
+            if (nbItems==0) {
+                cerr << "ERROR: Dataset is empty: " << this->_bankNames[i] << endl;
+                exit(1);
+            }
+
     		//size_t nbBank_ = bank->getCompositionNb();
     		SimkaBankTemp* simkaBank = new SimkaBankTemp(bank, this->_maxNbReads*this->_nbBankPerDataset[i]);
     		//banksToDelete.push_back(simkaBank);
@@ -817,7 +844,7 @@ public:
 
 			string tempDir = this->_outputDirTemp + "/temp/" + this->_bankNames[i];
 
-			string command = "nohup " + _execDir + "/simkaCountProcess " + _execDir + "/simkaCount ";
+			string command = "nohup " + _execDir + "simkaCountProcess " + _execDir + "simkaCount ";
 			command += " " + string(STR_KMER_SIZE) + " " + SimkaAlgorithm<>::toString(this->_kmerSize);
 			command += " " + string("-out-tmp-simka") + " " + this->_outputDirTemp;
 			command += " " + string("-out-tmp") + " " + tempDir;
@@ -983,7 +1010,7 @@ public:
 
 				filenameQueue.push_back(datasetId);
 
-				string command = "nohup " + _execDir + "/simkaMerge ";
+				string command = "nohup " + _execDir + "simkaMerge ";
 				command += " " + string(STR_KMER_SIZE) + " " + SimkaAlgorithm<>::toString(this->_kmerSize);
 				command += " " + string(STR_URI_INPUT) + " " + this->_inputFilename;
 				command += " " + string("-out-tmp-simka") + " " + this->_outputDirTemp;
